# Generated by Django 4.0.5 on 2022-06-24 06:35

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('plans_shared', '0003_erpsubscription_company'),
        ('accounts_shared', '0002_businessclient_creditlimit_and_more'),
    ]

    operations = [
        migrations.AddField(
            model_name='company',
            name='plan',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='companies', to='plans_shared.plan'),
        ),
    ]
