# Generated by Django 4.0.5 on 2022-06-23 14:01

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('accounting_shared', '0001_initial'),
        ('accounts_shared', '0001_initial'),
    ]

    operations = [
        migrations.AddField(
            model_name='businessclient',
            name='creditLimit',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='businessClient', to='accounting_shared.creditlimit'),
        ),
        migrations.AddField(
            model_name='businessclient',
            name='receivableAccount',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='accounting_shared.chartaccount'),
        ),
        migrations.AddField(
            model_name='consumerclient',
            name='creditLimit',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='consumerClient', to='accounting_shared.creditlimit'),
        ),
        migrations.AddField(
            model_name='consumerclient',
            name='receivableAccount',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='accounting_shared.chartaccount'),
        ),
        migrations.AddField(
            model_name='supplier',
            name='creditLimit',
            field=models.OneToOneField(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, related_name='supplier', to='accounting_shared.creditlimit'),
        ),
        migrations.AddField(
            model_name='supplier',
            name='payableAccount',
            field=models.ForeignKey(blank=True, null=True, on_delete=django.db.models.deletion.SET_NULL, to='accounting_shared.chartaccount'),
        ),
    ]
